@@ -10,30 +10,14 @@ package Devel::Cover::Condition;
 use strict;
 use warnings;
 
-our $VERSION = "0.49";
+our $VERSION = "0.50";
 
-use base "Devel::Cover::Criterion";
+use base "Devel::Cover::Branch";
 
-sub uncoverable { $_[0][2][shift] }
-sub covered     { (scalar grep $_, @{$_[0][0]}) }
-sub total       { (scalar          @{$_[0][0]}) }
-sub percentage
-{
-    my $t = $_[0]->total;
-    sprintf "%3d", $t ? $_[0]->covered / $t * 100 : 0
-}
-sub error
-{
-    for (0 .. $#{$_[0][0]})
-    {
-        return 1 if $_[0][0][$_] xor !$_[0][2][$_]
-    }
-    0
-}
-sub text        { "$_[0][1]{left} $_[0][1]{op} $_[0][1]{right}" }
-sub type        { $_[0][1]{type} }
 sub pad         { $_[0][0][$_] ||= 0 for 0 .. $_[0]->count - 1 }
 sub values      { $_[0]->pad; @{$_[0][0]} }
+sub text        { "$_[0][1]{left} $_[0][1]{op} $_[0][1]{right}" }
+sub type        { $_[0][1]{type} }
 sub count       { require Carp; Carp::confess "count() must be overridden" }
 sub headers     { require Carp; Carp::confess "headers() must be overridden" }
 
@@ -47,17 +31,29 @@ sub calculate_summary
     $self->pad;
 
     my $t = $self->total;
+    my $u = $self->uncoverable;
     my $c = $self->covered;
+    my $e = $self->error;
 
-    $s->{$file}{condition}{total}   += $t;
-    $s->{$file}{total}{total}       += $t;
-    $s->{Total}{condition}{total}   += $t;
-    $s->{Total}{total}{total}       += $t;
+    $s->{$file}{condition}{total}       += $t;
+    $s->{$file}{total}{total}           += $t;
+    $s->{Total}{condition}{total}       += $t;
+    $s->{Total}{total}{total}           += $t;
 
-    $s->{$file}{condition}{covered} += $c;
-    $s->{$file}{total}{covered}     += $c;
-    $s->{Total}{condition}{covered} += $c;
-    $s->{Total}{total}{covered}     += $c;
+    $s->{$file}{condition}{uncoverable} += $u;
+    $s->{$file}{total}{uncoverable}     += $u;
+    $s->{Total}{condition}{uncoverable} += $u;
+    $s->{Total}{total}{uncoverable}     += $u;
+
+    $s->{$file}{condition}{covered}     += $c;
+    $s->{$file}{total}{covered}         += $c;
+    $s->{Total}{condition}{covered}     += $c;
+    $s->{Total}{total}{covered}         += $c;
+
+    $s->{$file}{condition}{error}       += $e;
+    $s->{$file}{total}{error}           += $e;
+    $s->{Total}{condition}{error}       += $e;
+    $s->{Total}{total}{error}           += $e;
 }
 
 1
@@ -88,7 +84,7 @@ Huh?
 
 =head1 VERSION
 
-Version 0.49 - 6th October 2004
+Version 0.50 - 25th October 2004
 
 =head1 LICENCE
 
