@@ -4,10 +4,10 @@ use strict;
 use warnings;
 use CGI;
 use Getopt::Long;
-use Devel::Cover::DB 0.49;
-use Devel::Cover::Truth_Table 0.49;
+use Devel::Cover::DB 0.50;
+use Devel::Cover::Truth_Table 0.50;
 
-our $VERSION = "0.49";
+our $VERSION = "0.50";
 
 #-------------------------------------------------------------------------------
 # Subroutine : get_coverage_for_line
@@ -43,10 +43,11 @@ sub get_summary_for_file {
                 percent => sprintf("%4.1f", $data->{$c}{percentage}),
                 ratio   => sprintf("%d / %d",
                     $data->{$c}{covered} || 0, $data->{$c}{total} || 0),
+                error   => $data->{$c}{error},
             };
         }
         else {
-            $summary{$c} = {percent => 'n/a', ratio => undef};
+            $summary{$c} = {percent => 'n/a', ratio => undef, error => undef};
         }
     }
     return \%summary;
@@ -164,14 +165,12 @@ sub bclass {
 # Notes      :
 #-------------------------------------------------------------------------------
 sub pclass {
-    my @c;
-    foreach my $p (@_) {
-        $p <  75 && do {push @c, $class[0]; next};
-        $p <  90 && do {push @c, $class[1]; next};
-        $p < 100 && do {push @c, $class[2]; next};
-        push @c, $class[3];
-    }
-    return wantarray ? @c : $c[0];
+    my ($p, $e) = @_;
+    return $class[3] unless $e;
+    $p <  75 && return $class[0];
+    $p <  90 && return $class[1];
+    $p < 100 && return $class[2];
+    $class[3]
 }
 
 #-------------------------------------------------------------------------------
@@ -192,7 +191,7 @@ sub _count_report {
     my $type = shift;
     my $data = shift;
     return map {{
-        class      => bclass($_->covered),
+        class      => bclass(!$_->error || $_->covered),
         percentage => $_->covered,
     }} @{$data->{$type}}
 }
@@ -204,7 +203,7 @@ sub _branch_report {
     return map {{
         percentage => sprintf("%.0f", $_->percentage),
         title      => sprintf("%s/%s", $_->[0][0] ? 'T' : '-', $_->[0][1] ? 'F' : '-'),
-        class      => pclass($_->percentage),
+        class      => pclass($_->percentage, $_->error),
         string     => sprintf($sfmt, bclass($_->[0][0]), bclass($_->[0][1])),
     }} @{$coverage->{branch}}
 }
@@ -216,7 +215,7 @@ sub _condition_report {
     return unless @tables;
     return map {{
         percentage => sprintf("%.0f", $_->[0]->percentage),
-        class      => pclass($_->[0]->percentage),
+        class      => pclass($_->[0]->percentage, $_->[0]->error),
         string     => $_->[0]->html(bclass(0,1)),
     }} @tables;
 }
@@ -255,7 +254,7 @@ sub print_html_header {
 
     print $fh <<"END_HTML";
 <!--
-This file was generated by Devel::Cover Version 0.49
+This file was generated by Devel::Cover Version 0.50
 Devel::Cover is copyright 2001-2004, Paul Johnson (pjcj\@cpan.org)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
@@ -287,8 +286,9 @@ sub print_summary {
     my $title    = shift;
     my $file     = shift;
     my $percent  = sprintf("%.1f", shift @_);
+    my $error    = shift;
     my $db       = shift;
-    my $class    = pclass($percent);
+    my $class    = pclass($percent, $error);
 
     my $meta     = $db->{meta}{$file};
 
@@ -389,7 +389,8 @@ END_HTML
                 $class = $popup = '';
             }
             else {
-                $class = sprintf(qq' class="%s"', pclass($pc));
+                $class = sprintf(qq' class="%s"',
+                                 pclass($pc, $summary->{$c}{error}));
                 $popup = sprintf(qq' title="%s"', $summary->{$c}{ratio});
                 if ($c =~ /branch|condition|subroutine/) {
                     $link = get_link($file, $c);
@@ -445,7 +446,10 @@ sub print_file_report {
     my $file_data   = $db->cover->file($fin);
 
     print_html_header($out, "File Coverage: $fin");
-    print_summary($out, 'File Coverage', $fin, $db->{summary}{$fin}{total}{percentage}, $db);
+    print_summary($out, 'File Coverage', $fin,
+                  $db->{summary}{$fin}{total}{percentage},
+                  $db->{summary}{$fin}{total}{error},
+                  $db);
     print_th($out, ['line', @$th, 'code']);
 
     while (my $sloc = <$in>) {
@@ -550,7 +554,10 @@ sub print_branch_report {
     open(my $out, '>', $fout) or warn("Can't open file '$fout' [$!]\n"), return;
 
     print_html_header($out, "Branch Coverage: $file");
-    print_summary($out, 'Branch Coverage', $file, $db->{summary}{$file}{branch}{percentage}, $db);
+    print_summary($out, 'Branch Coverage', $file,
+                  $db->{summary}{$file}{branch}{percentage},
+                  $db->{summary}{$file}{branch}{error},
+                  $db);
     print_th($out, ['line', '%', 'coverage', 'branch'], {coverage => 2});
 
     my $fmt = qq'<tr><td class="h">%s</td>'
@@ -565,7 +572,7 @@ sub print_branch_report {
             my @tf = $x->values;
             printf $out ($fmt,
                 $n++ > 0 ? '' : qq'<a id="L$line">$line</a>',
-                pclass($x->percentage), $x->percentage,
+                pclass($x->percentage, $x->error), $x->percentage,
                 bclass($tf[0]), bclass($tf[1]),
                 escape_HTML($x->text),
             );
@@ -590,7 +597,10 @@ sub print_condition_report {
     open(my $out, '>', $fout) or warn("Can't open file '$fout' [$!]\n"), return;
 
     print_html_header($out, "Condition Coverage: $file");
-    print_summary($out, 'Condition Coverage', $file, $db->{summary}{$file}{condition}{percentage}, $db);
+    print_summary($out, 'Condition Coverage', $file,
+                  $db->{summary}{$file}{condition}{percentage},
+                  $db->{summary}{$file}{condition}{error},
+                  $db);
     print_th($out, ['line', '%', 'coverage', 'condition']);
 
     my $fmt = qq'<tr><td class="h">%s</td>'
@@ -604,7 +614,7 @@ sub print_condition_report {
         foreach my $x (@tt) {
             printf $out ($fmt,
                 $n++ > 0 ? '' : qq'<a id="L$line">$line</a>',
-                pclass($x->[0]->percentage), $x->[0]->percentage,
+                pclass($x->[0]->percentage, $x->[0]->error), $x->[0]->percentage,
                 '<div>' . $x->[0]->html(bclass(0,1)) . '</div>',
                 escape_HTML($x->[1]),
             );
@@ -629,7 +639,10 @@ sub print_sub_report {
     open(my $out, '>', $fout) or warn("Can't open file '$fout' [$!]\n"), return;
 
     print_html_header($out, "Subroutine Coverage: $file");
-    print_summary($out, 'Subroutine Coverage', $file, $db->{summary}{$file}{subroutine}{percentage}, $db);
+    print_summary($out, 'Subroutine Coverage', $file,
+                  $db->{summary}{$file}{subroutine}{percentage},
+                  $db->{summary}{$file}{subroutine}{error},
+                  $db);
     print_th($out, ['line', 'subroutine']);
 
     my $fmt = qq'<tr><td class="h">%s</td>'
@@ -641,7 +654,7 @@ sub print_sub_report {
         foreach my $x (@$l) {
             printf $out ($fmt,
                 $n++ > 0 ? '' : qq'<a id="L$line">$line</a>',
-                pclass($x->percentage),
+                pclass($x->percentage, $x->error),
                 escape_HTML($x->name),
             );
         }
@@ -759,7 +772,7 @@ Devel::Cover
 
 =head1 VERSION
 
-Version 0.49 - 6th October 2004
+Version 0.50 - 25th October 2004
 
 =head1 LICENCE
 
